@@ -68,6 +68,9 @@ enum {
   TT_SKETCH_COLORS,
   TT_TEXT,
   TT_LANG,
+  TT_MAPS,
+  TT_MAPS_OFFSET,
+  TT_LOG,
 };
 
 
@@ -78,6 +81,9 @@ static const thstok thtt_cfg[] = {
   {"export", TT_EXPORT},
   {"lang", TT_LANG},
   {"language", TT_LANG},
+  {"log", TT_LOG},
+  {"maps", TT_MAPS},
+  {"maps-offset", TT_MAPS_OFFSET},
   {"select", TT_SELECT},
   {"setup3d", TT_SETUP3D},
   {"sketch-colors", TT_SKETCH_COLORS},
@@ -90,6 +96,23 @@ static const thstok thtt_cfg[] = {
 };
 
 
+enum {
+  TT_LOG_ALL,
+  TT_LOG_NONE,
+  TT_LOG_UNKNOWN, 
+  TT_LOG_EXTEND, 
+};
+
+
+static const thstok thtt_cfg_log[] = {
+  {"all", TT_LOG_ALL},
+  {"extend", TT_LOG_EXTEND},
+  {"none", TT_LOG_NONE},
+  {NULL, TT_LOG_UNKNOWN}
+};
+
+
+
 //const char * THCCC_ENCODING = "# Character encoding of this configuration "//  "file.\n";
 const char * THCCC_ENCODING = "";
 const char * THCCC_SOURCE = "# Name of the source file.\n";
@@ -111,12 +134,26 @@ thconfig::thconfig()
   this->outcs_sumn = 0.0;
 
   this->sketch_colors = 256;
+  this->use_maps = true;
+  this->use_maps_offset = true;
+
+  this->reproducible_output = false;
+
+  this->log_extend = false;
 
   this->tmp3dSMP = 1.0;
   this->tmp3dWALLSMP = 0.1;
   this->tmp3dMAXDIMD = 5.0;
   this->sketch_warp = THSKETCH_WARP_IDLINE;
 
+  this->ibbx[0] = thnan;
+  this->ibbx[1] = thnan;
+  this->ibbx[2] = thnan;
+  this->ibbx[3] = thnan;
+  this->ibbx_def = false;
+
+  this->m_decl_out_of_geomag_range = false;
+
 #ifdef THWIN32
   thbuffer * tmpbf = &(this->bf1);
   // set search path according to Windows registers
@@ -472,13 +509,57 @@ void thconfig::load()
             if (valuemb.get_size() > 0) {
               sv = thmatch_token(valuemb.get_buffer()[0], thtt_bool);
               if (sv == TT_UNKNOWN_BOOL)
-                ththrow(("invalid auto-join sqitch -- %s", valuemb.get_buffer()[0]))
+                ththrow(("invalid auto-join switch -- %s", valuemb.get_buffer()[0]))
               this->auto_join = (sv == TT_TRUE);
             } else {
               ththrow(("missing auto-join switch"))
             }
             break;
-  
+
+          case TT_MAPS:
+            if (valuemb.get_size() > 0) {
+              sv = thmatch_token(valuemb.get_buffer()[0], thtt_bool);
+              if (sv == TT_UNKNOWN_BOOL)
+                ththrow(("invalid maps switch -- %s", valuemb.get_buffer()[0]))
+              this->use_maps = (sv == TT_TRUE);
+            } else {
+              ththrow(("missing maps switch"))
+            }
+            break;
+            
+          case TT_MAPS_OFFSET:
+            if (valuemb.get_size() > 0) {
+              sv = thmatch_token(valuemb.get_buffer()[0], thtt_bool);
+              if (sv == TT_UNKNOWN_BOOL)
+                ththrow(("invalid maps switch -- %s", valuemb.get_buffer()[0]))
+              this->use_maps_offset = (sv == TT_TRUE);
+            } else {
+              ththrow(("missing maps-offset switch"))
+            }
+            break;
+
+          case TT_LOG:
+            if (valuemb.get_size() > 0) {
+              sv = thmatch_token(valuemb.get_buffer()[0], thtt_cfg_log);
+              if (sv == TT_LOG_UNKNOWN)
+                ththrow(("invalid log switch -- %s", valuemb.get_buffer()[0]))
+              switch (sv) {
+                case TT_LOG_ALL:
+                    this->log_extend = true;
+                    break;
+                case TT_LOG_NONE:
+                    this->log_extend = false;
+                    break;
+                case TT_LOG_EXTEND:
+                    this->log_extend = true;
+                    break;
+              }
+            } else {
+              ththrow(("missing log switch"))
+            }
+            break;
+
+
           case TT_SELECT:
             this->selector.parse_selection(false, valuemb.get_size(), valuemb.get_buffer());
             break;
@@ -573,7 +654,6 @@ void thconfig::load_dbcommand(thmbuffer * valmb) {
   // vlozi ho do databazy
   // kazdy riadok prida do prikazov na ulozenie
 
-  thdataobject * objptr;  // pointer to the newly created object
   thcmd_option_desc optd;  // option descriptor
   char * ln, * opt;
   char ** opts;
@@ -592,12 +672,12 @@ void thconfig::load_dbcommand(thmbuffer * valmb) {
     dbptr->csrc.name = osrc.name;
 
 
-    objptr = dbptr->create(this->cfg_file.get_cmd(), osrc);
+    auto objptr = dbptr->create(this->cfg_file.get_cmd(), osrc);
     if (objptr == NULL)
       ththrow(("unknown command -- %s", this->cfg_file.get_cmd()));
 
     if (objptr->get_class_id() == TT_LAYOUT_CMD) {
-      ((thlayout*)objptr)->m_pconfig = this;
+      ((thlayout*)objptr.get())->m_pconfig = this;
     }
 
     thencode(&this->bf1, this->cfg_file.get_line(), this->cfg_file.get_cif_encoding());  
@@ -693,7 +773,7 @@ void thconfig::load_dbcommand(thmbuffer * valmb) {
     }
     
     // vlozi objekt do databazy
-    dbptr->insert(objptr);
+    dbptr->insert(std::move(objptr));
   }
     
   // put everything into try block and throw exception, if error
@@ -866,8 +946,12 @@ bool thconfig::get_outcs_mag_decl(double year, double & decl)
   double x, y, z, lat, lon, alt;
   if (!this->get_outcs_center(x, y, z))
     return false;
+  if (year < 1900.0)
+    ththrow(("automatic declination calculation before 1900 not supported, please specify declination explicitly"))
+  if (year > double(thgeomag_minyear + thgeomag_step * (thgeomag_maxmindex + 3)))
+    ththrow(("automatic declination calculation after %d not supported, please specify declination explicitly", thgeomag_minyear + thgeomag_step * (thgeomag_maxmindex + 3)))
   if ((year < double(thgeomag_minyear)) || (year > double(thgeomag_minyear + thgeomag_step * (thgeomag_maxmindex + 1))))
-    return false;
+    this->m_decl_out_of_geomag_range = true;
   thcs2cs(thcs_get_params(this->outcs), "+proj=latlong +datum=WGS84", x, y, z, lon, lat, alt);
   decl = thgeomag(lat, lon, alt, year);
   return true;
